using System;
using System.Collections;
using Zcu.Mve.Core;

namespace Zcu.Mve.Visualization
{
	/// <summary>
	/// Specialization of UnstrGrid. 
	/// Can contain only Triangle, TriangleStrip, TriangleFan, Line, PolyLine cells, Polygon.
	/// Attributes are not limited.
	/// </summary>
	public class Mesh : Zcu.Mve.Visualization.UnstrGridEigCell
	{
		/// <summary>
		/// Creates emtpy mesh.
		/// Eigen cells are: Triangle, TriangleStrip, TriangleFan, Line, PolyLine, Polygon.
		/// </summary>
		public Mesh()
		{
			eigCells.Add(typeof(Zcu.Mve.Visualization.Triangle), null);
			eigCells.Add(typeof(Zcu.Mve.Visualization.TriangleFan), null);
			eigCells.Add(typeof(Zcu.Mve.Visualization.TriangleStrip), null);
			eigCells.Add(typeof(Zcu.Mve.Visualization.Line), null);
			eigCells.Add(typeof(Zcu.Mve.Visualization.PolyLine), null);
			eigCells.Add(typeof(Zcu.Mve.Visualization.Polygon), null);
		}

		/// <summary>
		/// Creates shallow copy of current mesh.
		/// Only array references are coppied.
		/// </summary>
		/// <returns>Shallow copy of current mesh.</returns>
		public new Mesh ShallowCopy()
		{
			Mesh outMesh = new Mesh();
      
			// Shallow copy
			outMesh.Points = this.Points;
			foreach (string cellid in this.GetCellIds())
			{
				outMesh.AddCells(cellid, this.GetCells(cellid));
				foreach (string attrid in this.GetCellAttrsIds(cellid))
				{
					outMesh.AddCellAttrs(cellid, attrid, this.GetCellAttrs(cellid, attrid));
				}
			}
			foreach (string attrid in this.GetPointAttrsIds())
			{
				outMesh.AddPointAttrs(attrid, this.GetPointAttrs(attrid));
			} 

			return outMesh;
		}

	} // class Mesh
} // namespace