using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace Zcu.Mve.Visualization
{
	/// <summary>
	/// Panel for RegGrid2DRenderer.
	/// </summary>
	public class RegGrid2DRendererPanel : System.Windows.Forms.Form
	{
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.StatusBar statusBar1;
		private System.Windows.Forms.StatusBarPanel statusBarPanel1;

		/// <summary>
		/// Picture to render.
		/// </summary>
		private Bitmap data;

		/// <summary>
		/// Minimum size of the renderer window.
		/// </summary>
		private const int MIN_WIDTH = 250;

		/// <summary>
		/// Offset for picture centering.
		/// </summary>
		private int offsetX = 0;

		/// <summary>
		/// Creates panel, initialize and set its size according to size of the picture.
		/// </summary>
		/// <param name="data">Picture to render.</param>
		public RegGrid2DRendererPanel(Bitmap data)
		{
			this.data = data;
			// Required for Windows Form Designer support
			InitializeComponent();
			// Nastaven rozmr aktivn plochy okna.
			if (data.Width <= RegGrid2DRendererPanel.MIN_WIDTH)
			{	// obrazek je prilis maly, jako sirka okna se pouzije minimalni sirka
				this.ClientSize = new Size(RegGrid2DRendererPanel.MIN_WIDTH, data.Height + 20);
				this.statusBar1.Size = new Size(RegGrid2DRendererPanel.MIN_WIDTH, 20);
				this.offsetX = (RegGrid2DRendererPanel.MIN_WIDTH - data.Width) / 2;
			}
			else
			{	// obrazek ma rozmer vetsi nez minimum, proto se jako sirka okna pouzije sirka obrazku
				this.ClientSize = new Size(data.Width, data.Height + 20);
				this.statusBar1.Size = new Size(data.Width, 20);
			}
			this.statusBarPanel1.Text = " Resolution of this picture:  " + data.Width + " x " + data.Height;
		} // RegGrid2DRendererPanel()

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.statusBar1 = new System.Windows.Forms.StatusBar();
			this.statusBarPanel1 = new System.Windows.Forms.StatusBarPanel();
			((System.ComponentModel.ISupportInitialize)(this.statusBarPanel1)).BeginInit();
			this.SuspendLayout();
			// 
			// statusBar1
			// 
			this.statusBar1.Font = new System.Drawing.Font("Tahoma", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(238)));
			this.statusBar1.Location = new System.Drawing.Point(0, 244);
			this.statusBar1.Name = "statusBar1";
			this.statusBar1.Panels.AddRange(new System.Windows.Forms.StatusBarPanel[] {
																						  this.statusBarPanel1});
			this.statusBar1.ShowPanels = true;
			this.statusBar1.Size = new System.Drawing.Size(292, 22);
			this.statusBar1.SizingGrip = false;
			this.statusBar1.TabIndex = 0;
			// 
			// statusBarPanel1
			// 
			this.statusBarPanel1.AutoSize = System.Windows.Forms.StatusBarPanelAutoSize.Spring;
			this.statusBarPanel1.Width = 292;
			// 
			// RegGrid2DRendererPanel
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.BackColor = System.Drawing.SystemColors.Control;
			this.ClientSize = new System.Drawing.Size(292, 266);
			this.Controls.Add(this.statusBar1);
			this.MaximizeBox = false;
			this.Name = "RegGrid2DRendererPanel";
			this.Text = "RegGrid2DRendererPanel";
			this.Resize += new System.EventHandler(this.RegGrid2DRendererPanel_Resize);
			((System.ComponentModel.ISupportInitialize)(this.statusBarPanel1)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// Render the picture on panel.
		/// </summary>
		/// <param name="e">Event.</param>
		protected override void OnPaint(PaintEventArgs e)
		{
			Graphics g = e.Graphics;
			g.DrawImage(data, 0, 0, this.ClientSize.Width, this.ClientSize.Height - 20);
			base.OnPaint (e);
		}

		/// <summary>
		/// Resize the renderer panel.
		/// </summary>
		/// <param name="sender">Sender.</param>
		/// <param name="e">Event.</param>
		private void RegGrid2DRendererPanel_Resize(object sender, System.EventArgs e)
		{
			this.Invalidate();
		} 

	} // class RegGrid2DRendererPanel
} // namespace
