using System;
using System.Collections;
using System.Xml;
using System.Diagnostics;
using Zcu.Mve.Core;

namespace Zcu.Mve.Visualization
{
	/// <summary>
	/// Object represent ortogonal, regular N dimensional grid.
	/// Structure consists of points only. 
	/// Point location is given implicitly. 
	/// Point with zero indices has [0,0,...,0] cooordinate values.
  /// Point with maximum indices has [1,1,...,1] cooordinate values.
  /// And vice versa.
  /// </summary>
	public class RegGridND : Visualization.GridND
	{
		/// <summary>
		/// For XmlLoader use only. Use parametric constructor instead.
		/// </summary>
		public RegGridND()
		{
		} // RegGridND()

		/// <summary>
		/// Creates empty grid
		/// </summary>
		/// <param name="sizes">Structure dimensions.</param>
		public RegGridND(params int[] sizes) : base(sizes)
		{
		} // RegGridND()

	

    /// <summary>
    /// Returns x, y coordinates of point with i, j indices.
    /// </summary>
    /// <param name="coords">Point coordinates. Count must be equal to structure dimension</param>
    /// <returns>new  instance of point</returns>
    public override PointND GetPoint(params int[] coords)
    {
		if (coords.Length!=this.Dimensions.Length)
		{
			throw new MveException("Coordinate count and RegGridND dimension must agree.");
		}
		PointND result = new PointND(coords.Length);

		for (int i = 0;i<coords.Length;i++)
			result.Values[i] = (double)coords[i]/Dimensions[i];

		return(result);            
    }
  } // class RegGridND
} // namespace